@@ -11,9 +11,16 @@ cache = Cache()
 @register.inclusion_tag('minimizer/tags/styles.html', takes_context=True)
 def minimizer_styles(context):
     timestamp = cache.get_timestamp()
+
+    # FIXME: optimize it.
+    styles = []
+    for style in get_minimizer_list(settings.STYLES, timestamp, 'css'):
+        is_less = os.path.splitext(style)[-1] == '.less'
+        styles.append([style, is_less])
+
     arguments = {
         'STATIC_URL': context['STATIC_URL'],
-        'styles': get_minimizer_list(settings.STYLES, timestamp, 'css')
+        'styles': styles
     }
 
     return arguments
